[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Guile-commits] GNU Guile branch, stable-2.0, updated. v2.0.7-163-g1adba
From: |
Andy Wingo |
Subject: |
[Guile-commits] GNU Guile branch, stable-2.0, updated. v2.0.7-163-g1adba49 |
Date: |
Sat, 09 Mar 2013 18:11:56 +0000 |
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU Guile".
http://git.savannah.gnu.org/cgit/guile.git/commit/?id=1adba49ab20ac283ca62963f115910f1cf7b63ad
The branch, stable-2.0 has been updated
via 1adba49ab20ac283ca62963f115910f1cf7b63ad (commit)
from 09b204d38756f0fa9ab4319874c8ce2838488dd0 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 1adba49ab20ac283ca62963f115910f1cf7b63ad
Author: Andy Wingo <address@hidden>
Date: Sat Mar 9 19:08:51 2013 +0100
Import `pipe-posix' module from gnulib.
* lib/Makefile.am:
* lib/pipe.c:
* m4/gnulib-cache.m4:
* m4/gnulib-comp.m4:
* m4/pipe.m4: Add pipe-posix module.
-----------------------------------------------------------------------
Summary of changes:
lib/Makefile.am | 11 ++++++++-
lib/{msvc-nothrow.c => pipe.c} | 45 ++++++++++++++++++++-------------------
m4/gnulib-cache.m4 | 3 +-
m4/gnulib-comp.m4 | 8 +++++++
m4/pipe.m4 | 15 +++++++++++++
5 files changed, 58 insertions(+), 24 deletions(-)
copy lib/{msvc-nothrow.c => pipe.c} (53%)
create mode 100644 m4/pipe.m4
diff --git a/lib/Makefile.am b/lib/Makefile.am
index 2fe0e82..5659286 100644
--- a/lib/Makefile.am
+++ b/lib/Makefile.am
@@ -21,7 +21,7 @@
# the same distribution terms as the rest of that program.
#
# Generated by gnulib-tool.
-# Reproduce by: gnulib-tool --import --dir=. --local-dir=gnulib-local
--lib=libgnu --source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests
--aux-dir=build-aux --lgpl=3 --no-conditional-dependencies --libtool
--macro-prefix=gl --no-vc-files accept alignof alloca-opt announce-gen
autobuild bind byteswap canonicalize-lgpl ceil clock-time close connect dirfd
duplocale environ extensions flock floor fpieee frexp full-read full-write func
gendocs getaddrinfo getpeername getsockname getsockopt git-version-gen
gitlog-to-changelog gnu-web-doc-update gnupload havelib iconv_open-utf
inet_ntop inet_pton isinf isnan ldexp lib-symbol-versions lib-symbol-visibility
libunistring listen localcharset locale log1p maintainer-makefile malloc-gnu
malloca nl_langinfo nproc open pipe2 putenv recv recvfrom regex rename select
send sendto setenv setsockopt shutdown socket stat-time stdlib strftime
striconveh string sys_stat times trunc verify vsnprintf warnings wchar
+# Reproduce by: gnulib-tool --import --dir=. --local-dir=gnulib-local
--lib=libgnu --source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests
--aux-dir=build-aux --lgpl=3 --no-conditional-dependencies --libtool
--macro-prefix=gl --no-vc-files accept alignof alloca-opt announce-gen
autobuild bind byteswap canonicalize-lgpl ceil clock-time close connect dirfd
duplocale environ extensions flock floor fpieee frexp full-read full-write func
gendocs getaddrinfo getpeername getsockname getsockopt git-version-gen
gitlog-to-changelog gnu-web-doc-update gnupload havelib iconv_open-utf
inet_ntop inet_pton isinf isnan ldexp lib-symbol-versions lib-symbol-visibility
libunistring listen localcharset locale log1p maintainer-makefile malloc-gnu
malloca nl_langinfo nproc open pipe-posix pipe2 putenv recv recvfrom regex
rename select send sendto setenv setsockopt shutdown socket stat-time stdlib
strftime striconveh string sys_stat times trunc verify vsnprintf warnings wchar
AUTOMAKE_OPTIONS = 1.5 gnits subdir-objects
@@ -1460,6 +1460,15 @@ EXTRA_DIST += pathmax.h
## end gnulib module pathmax
+## begin gnulib module pipe-posix
+
+
+EXTRA_DIST += pipe.c
+
+EXTRA_libgnu_la_SOURCES += pipe.c
+
+## end gnulib module pipe-posix
+
## begin gnulib module pipe2
libgnu_la_SOURCES += pipe2.c
diff --git a/m4/gnulib-cache.m4 b/m4/gnulib-cache.m4
index f8a9737..fe243f8 100644
--- a/m4/gnulib-cache.m4
+++ b/m4/gnulib-cache.m4
@@ -27,7 +27,7 @@
# Specification in the form of a command-line invocation:
-# gnulib-tool --import --dir=. --local-dir=gnulib-local --lib=libgnu
--source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests
--aux-dir=build-aux --lgpl=3 --no-conditional-dependencies --libtool
--macro-prefix=gl --no-vc-files accept alignof alloca-opt announce-gen
autobuild bind byteswap canonicalize-lgpl ceil clock-time close connect dirfd
duplocale environ extensions flock floor fpieee frexp full-read full-write func
gendocs getaddrinfo getpeername getsockname getsockopt git-version-gen
gitlog-to-changelog gnu-web-doc-update gnupload havelib iconv_open-utf
inet_ntop inet_pton isinf isnan ldexp lib-symbol-versions lib-symbol-visibility
libunistring listen localcharset locale log1p maintainer-makefile malloc-gnu
malloca nl_langinfo nproc open pipe2 putenv recv recvfrom regex rename select
send sendto setenv setsockopt shutdown socket stat-time stdlib strftime
striconveh string sys_stat times trunc verify vsnprintf warnings wchar
+# gnulib-tool --import --dir=. --local-dir=gnulib-local --lib=libgnu
--source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests
--aux-dir=build-aux --lgpl=3 --no-conditional-dependencies --libtool
--macro-prefix=gl --no-vc-files accept alignof alloca-opt announce-gen
autobuild bind byteswap canonicalize-lgpl ceil clock-time close connect dirfd
duplocale environ extensions flock floor fpieee frexp full-read full-write func
gendocs getaddrinfo getpeername getsockname getsockopt git-version-gen
gitlog-to-changelog gnu-web-doc-update gnupload havelib iconv_open-utf
inet_ntop inet_pton isinf isnan ldexp lib-symbol-versions lib-symbol-visibility
libunistring listen localcharset locale log1p maintainer-makefile malloc-gnu
malloca nl_langinfo nproc open pipe-posix pipe2 putenv recv recvfrom regex
rename select send sendto setenv setsockopt shutdown socket stat-time stdlib
strftime striconveh string sys_stat times trunc verify vsnprintf warnings wchar
# Specification in the form of a few gnulib-tool.m4 macro invocations:
gl_LOCAL_DIR([gnulib-local])
@@ -84,6 +84,7 @@ gl_MODULES([
nl_langinfo
nproc
open
+ pipe-posix
pipe2
putenv
recv
diff --git a/m4/gnulib-comp.m4 b/m4/gnulib-comp.m4
index 8dc2691..3a8172b 100644
--- a/m4/gnulib-comp.m4
+++ b/m4/gnulib-comp.m4
@@ -146,6 +146,7 @@ AC_DEFUN([gl_EARLY],
# Code from module nproc:
# Code from module open:
# Code from module pathmax:
+ # Code from module pipe-posix:
# Code from module pipe2:
# Code from module putenv:
# Code from module raise:
@@ -545,6 +546,11 @@ AC_SUBST([LTALLOCA])
fi
gl_FCNTL_MODULE_INDICATOR([open])
gl_PATHMAX
+ gl_FUNC_PIPE
+ if test $HAVE_PIPE = 0; then
+ AC_LIBOBJ([pipe])
+ fi
+ gl_UNISTD_MODULE_INDICATOR([pipe])
gl_FUNC_PIPE2
gl_UNISTD_MODULE_INDICATOR([pipe2])
gl_FUNC_PUTENV
@@ -994,6 +1000,7 @@ AC_DEFUN([gl_FILE_LIST], [
lib/nproc.h
lib/open.c
lib/pathmax.h
+ lib/pipe.c
lib/pipe2.c
lib/printf-args.c
lib/printf-args.h
@@ -1183,6 +1190,7 @@ AC_DEFUN([gl_FILE_LIST], [
m4/off_t.m4
m4/open.m4
m4/pathmax.m4
+ m4/pipe.m4
m4/pipe2.m4
m4/printf.m4
m4/putenv.m4
diff --git a/m4/pipe.m4 b/m4/pipe.m4
new file mode 100644
index 0000000..5831283
--- /dev/null
+++ b/m4/pipe.m4
@@ -0,0 +1,15 @@
+# pipe.m4 serial 2
+dnl Copyright (C) 2010-2013 Free Software Foundation, Inc.
+dnl This file is free software; the Free Software Foundation
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+
+AC_DEFUN([gl_FUNC_PIPE],
+[
+ AC_REQUIRE([gl_UNISTD_H_DEFAULTS])
+
+ AC_CHECK_FUNCS_ONCE([pipe])
+ if test $ac_cv_func_pipe != yes; then
+ HAVE_PIPE=0
+ fi
+])
hooks/post-receive
diff --git a/lib/msvc-nothrow.c b/lib/pipe.c
similarity index 53%
copy from lib/msvc-nothrow.c
copy to lib/pipe.c
index c17a9a2..fc11967 100644
--- a/lib/msvc-nothrow.c
+++ b/lib/pipe.c
@@ -1,6 +1,5 @@
-/* Wrappers that don't throw invalid parameter notifications
- with MSVC runtime libraries.
- Copyright (C) 2011-2013 Free Software Foundation, Inc.
+/* Create a pipe.
+ Copyright (C) 2009-2013 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
@@ -18,32 +17,34 @@
#include <config.h>
/* Specification. */
-#include "msvc-nothrow.h"
+#include <unistd.h>
-/* Get declarations of the native Windows API functions. */
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
+#if (defined _WIN32 || defined __WIN32__) && ! defined __CYGWIN__
+/* Native Windows API. */
-#include "msvc-inval.h"
+/* Get _pipe(). */
+# include <io.h>
-#undef _get_osfhandle
+/* Get _O_BINARY. */
+# include <fcntl.h>
-#if HAVE_MSVC_INVALID_PARAMETER_HANDLER
-intptr_t
-_gl_nothrow_get_osfhandle (int fd)
+int
+pipe (int fd[2])
{
- intptr_t result;
-
- TRY_MSVC_INVAL
- {
- result = _get_osfhandle (fd);
- }
- CATCH_MSVC_INVAL
+ /* Mingw changes fd to {-1,-1} on failure, but this violates
+ http://austingroupbugs.net/view.php?id=467 */
+ int tmp[2];
+ int result = _pipe (tmp, 4096, _O_BINARY);
+ if (!result)
{
- result = (intptr_t) INVALID_HANDLE_VALUE;
+ fd[0] = tmp[0];
+ fd[1] = tmp[1];
}
- DONE_MSVC_INVAL;
-
return result;
}
+
+#else
+
+# error "This platform lacks a pipe function, and Gnulib doesn't provide a
replacement. This is a bug in Gnulib."
+
#endif
--
GNU Guile
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [Guile-commits] GNU Guile branch, stable-2.0, updated. v2.0.7-163-g1adba49,
Andy Wingo <=